#
# spec file
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor rx%{nil}
%if "%{flavor}" == ""
%define pname newlib
%else
%define cross_arch %{flavor}
%define pname cross-%{cross_arch}-newlib-devel
%endif
%if "%{flavor}" == "riscv64"
%define gcc_cross_arch %{cross_arch}-elf
%define target %{cross_arch}-elf
%else
%define gcc_cross_arch %{cross_arch}
%define target %{cross_arch}
%endif
%if "%{cross_arch}" == "epiphany" || "%{cross_arch}" == "riscv32" || "%{cross_arch}" == "rl78" || "%{cross_arch}" == "rx"
%define target %{cross_arch}-elf
%endif
%if "%{cross_arch}" == "arm-none"
%define target %{cross_arch}-eabi
%endif
%if "%{cross_arch}" == "spu"
%define sysroot %{_prefix}/spu
%else
%define sysroot %{_prefix}/%{target}/sys-root
%endif
# In the staging/ring projects, we don't want to build the unneeded packages
%bcond_with ringdisabled
Name:           %{pname}
Version:        4.1.0
Release:        2.1
Summary:        C library intended for use on embedded systems
License:        BSD-3-Clause AND MIT AND LGPL-2.0-or-later AND ISC
Group:          Development/Libraries/Cross
URL:            https://sourceware.org/newlib/
Source0:        ftp://sourceware.org/pub/newlib/newlib-%{version}.tar.gz
Patch1:         epiphany-fixes.diff
%if "%{flavor}" == ""
BuildArch:      noarch
%else
BuildRequires:  cross-%{gcc_cross_arch}-gcc%{gcc_version}-bootstrap
BuildRequires:  fdupes
%if "%{cross_arch}" != "arm-none" && "%{cross_arch}" != "arm" && %{with ringdisabled}
ExclusiveArch:  do-not-build
%endif
%endif

%description
Newlib is a C library intended for use on embedded systems. It is a
conglomeration of several library parts, all under free software licenses
that make them easily usable on embedded products.

%prep
%setup -q -n newlib-%{version}
%patch1 -p1

%build
%if "%{flavor}" != ""
mkdir build-dir
cd build-dir
# On %%ix86 hosts newlib is documented to be buildable as shared library via --with-newlib,
# but it fails to build for us and we don't need a host library at the moment.
../configure \
	--prefix=%{_prefix} --libdir=%{_libdir} --mandir=%{_mandir} --infodir=%{_infodir} \
	--target=%{target} \
	--with-build-sysroot=%{sysroot}
%ifarch %{ix86}
%if 0
	--with-newlib \
%endif
%endif
	CFLAGS="%{optflags}"

%make_build
%endif

%install
%if "%{flavor}" != ""
# All binaries built are for the target architecture - don't damage them.
export NO_BRP_STRIP_DEBUG=true
export NO_DEBUGINFO_STRIP_DEBUG=true
%define __debug_install_post %{nil}
: >debugfiles.list
: >debugsourcefiles.list
: >debugsources.list

cd build-dir
%make_install
%fdupes %{buildroot}
%endif

%files
%if "%{flavor}" == ""
%license COPYING.NEWLIB COPYING.LIBGLOSS COPYING COPYING.LIB COPYING3 COPYING3.LIB
%doc newlib/README newlib/NEWS
%else
%{_prefix}/%{target}/
%endif

%changelog
* Wed Jun  9 2021 Dirk Müller <dmueller@suse.com>
- disable all but the arm dependencies for ring
* Mon Mar  8 2021 Richard Biener <rguenther@suse.com>
- Update to v4.1.0
  * fixes for regressions to pow/powf and tgamma functions
  * RISC-V semihosting support
  * RISC-V and arm patches
  * additional out-of-bounds checking for malloc/nano-malloc family
    [bsc#1183172, CVE-2021-3420]
  * various fixes to makedocbook for python 3.8
  * multiple standard/accuracy fixes to libm math routines
  * C-SKY port
  * support for Armv8-R aarch64 added
  * move of __tzrules_struct from time.h to internal header
  * math additions/improvements for RISC-V and arm
  * all arm code converted to use unified syntax for Thumb1
  * fenv support added for multiple platforms
  * hard float support for PowerPC taken from FreeBSD
  * advertising clause removed from BSD licenses
  * various other fixes
* Tue Dec  8 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Use _multibuild for building all flavors.
- Remove unused makeinfo build dependency.
- Omit all build steps from base flavor, it just packages
  various documentation files.
- Remove deprecated stuff from spec file.
* Mon Dec  7 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Use defined gcc version for all architectures
* Tue Oct 27 2020 Matthew Trescott <matthewtrescott@gmail.com>
- Update to v3.3.0
  * Fixes assembly of trap.S when building ARM multilibs (related
    to [bsc#1106014]
- Remove unused configure flag --with-multilib-list. Newlib's configure
  script obtains this information from the GCC used to build it.
* Sun Jun 23 2019 Andreas Färber <afaerber@suse.de>
- Update to v3.1.0
* Mon May 27 2019 matz@suse.com
- On riscv64 force gcc 8 as bootstrap compiler
* Mon Dec 24 2018 Jan Engelhardt <jengelh@inai.de>
- Trim redundant license mention.
* Sat May 12 2018 afaerber@suse.de
- Add riscv64 target
* Sat May 12 2018 afaerber@suse.de
- Update SPDX syntax
* Sun Mar 11 2018 afaerber@suse.de
- Add arm-none-eabi target
* Sun Mar 11 2018 afaerber@suse.de
- Update to v3.0.0
* Sun Mar 11 2018 afaerber@suse.de
- Prepare for %%cross_arch with dashes by consistently quoting
- Leave the choice of cross-*-binutils to cross-*-gcc*
- Update to v2.5.0
* Wed Jan 24 2018 rguenther@suse.com
- Handle debugsources.list to debugsourcefiles.list rename of new rpm.
* Fri Jul  1 2016 rguenther@suse.com
- Add rx and epiphany targets
* Tue May 17 2016 afaerber@suse.de
- Drop newlib-rpmlintrc
* Sat May 14 2016 afaerber@suse.de
- Apply epiphany-fixes.diff not only to cross builds (.spec.in) but
  also in newlib.spec, to please factory-auto checker (sr#395228)
* Fri May 13 2016 afaerber@suse.de
- Prepare rl78 target
- Update to 2.4.0
  * Info files are no longer built
  * Package all license and read-me files
- Clean up makeinfo dependency
- Drop cross .spec files in preparation for Factory submission
* Mon Jul 20 2015 afaerber@suse.de
- Update to 2.2.0.20150623
- Add cross-rx-newlib-devel package
- Revert installing files to sysroot
* Fri Jul 10 2015 afaerber@suse.de
- Switch cross template to gcc5
* Mon Apr  6 2015 afaerber@suse.de
- Install target files to sysroot
* Sat Nov  1 2014 afaerber@suse.de
- Enable native builds
* Fri Oct 31 2014 afaerber@suse.de
- epiphany-fixes.diff: Drop executable permissions of
  libepiphany.a and crt0.o
* Fri Oct 31 2014 afaerber@suse.de
- Turn cross-epiphany-newlib into generic newlib package
  * Rename packages to -devel to avoid empty -newlib packages
* Tue Oct 21 2014 afaerber@suse.de
- Update to official 2.1.0 tarball
  * Drop portability.patch
* Tue Sep 30 2014 afaerber@suse.de
- Initial
